@@ -31,6 +31,7 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 
 import pyppmd
 import pyzstd
+from zipfile_deflate64 import deflate64  # type: ignore
 from Cryptodome.Cipher import AES
 from Cryptodome.Random import get_random_bytes
 
@@ -45,6 +46,7 @@ from py7zr.properties import (
     FILTER_COPY,
     FILTER_CRYPTO_AES256_SHA256,
     FILTER_DEFLATE,
+    FILTER_DEFLATE64,
     FILTER_DELTA,
     FILTER_IA64,
     FILTER_LZMA,
@@ -261,6 +263,26 @@ class DeflateDecompressor(ISevenZipDecompressor):
         return self._decompressor.decompress(data)
 
 
+class Deflate64Compressor(ISevenZipCompressor):
+    def __init__(self):
+        raise RuntimeError("Deflate64 compression not implemented yet")
+
+
+class Deflate64Decompressor(ISevenZipDecompressor):
+    def __init__(self):
+        self.flushed = False
+        self._decompressor = deflate64.Deflate64()
+
+    def decompress(self, data: Union[bytes, bytearray, memoryview], max_length: int = -1) -> bytes:
+        if len(data) == 0:
+            if self.flushed:
+                return b""
+            else:
+                self.flushed = True
+                return self._decompressor.flush()
+        return self._decompressor.decompress(data)
+
+
 class CopyCompressor(ISevenZipCompressor):
     def compress(self, data: Union[bytes, bytearray, memoryview]) -> bytes:
         return bytes(data)
@@ -289,10 +311,8 @@ class PpmdDecompressor(ISevenZipDecompressor):
         self.decoder = pyppmd.Ppmd7Decoder(order, mem)
 
     def decompress(self, data: Union[bytes, bytearray, memoryview], max_length=-1) -> bytes:
-        if max_length <= 0:
-            return self.decoder.decode(data, 1)
-        if len(data) == 0:
-            return self.decoder.flush(max_length)
+        if len(data) == 0 and self.decoder.needs_input:
+            return self.decoder.decode(b"\0", max_length)
         return self.decoder.decode(data, max_length)
 
 
@@ -497,6 +517,7 @@ algorithm_class_map = {
     FILTER_BZIP2: (bz2.BZ2Compressor, bz2.BZ2Decompressor),
     FILTER_COPY: (CopyCompressor, CopyDecompressor),
     FILTER_DEFLATE: (DeflateCompressor, DeflateDecompressor),
+    FILTER_DEFLATE64: (Deflate64Compressor, Deflate64Decompressor),
     FILTER_CRYPTO_AES256_SHA256: (AESCompressor, AESDecompressor),
     FILTER_X86: (BCJEncoder, BCJDecoder),
     FILTER_ARM: (BcjArmEncoder, BcjArmDecoder),
@@ -1005,6 +1026,14 @@ class SupportedMethods:
             "filter_id": FILTER_BROTLI,
             "type": MethodsType.compressor,
         },
+        {
+            "id": COMPRESSION_METHOD.MISC_DEFLATE64,
+            "name": "DEFLATE64",
+            "native": False,
+            "need_prop": False,
+            "filter_id": FILTER_DEFLATE64,
+            "type": MethodsType.compressor,
+        },
         {
             "id": COMPRESSION_METHOD.CRYPT_AES256_SHA256,
             "name": "7zAES",
@@ -1139,7 +1168,7 @@ def get_methods_names(coders_lists: List[List[dict]]) -> List[str]:
         "LZMA",
         "BZip2",
         "DEFLATE",
-        "DEFLATE64*",
+        "DEFLATE64",
         "delta",
         "COPY",
         "PPMd",
@@ -1157,7 +1186,6 @@ def get_methods_names(coders_lists: List[List[dict]]) -> List[str]:
     unsupported_methods = {
         COMPRESSION_METHOD.P7Z_BCJ2: "BCJ2*",
         COMPRESSION_METHOD.MISC_LZ4: "LZ4*",
-        COMPRESSION_METHOD.MISC_DEFLATE64: "DEFLATE64*",
     }
     methods_names = []
     for coders in coders_lists:
